/*
 *  $Id: PrettyPrintTest.java,v 1.2 2004/10/28 15:42:39 mriem Exp $
 *
 *  Copyright (c) 2001-2004, RIACA, Technische Universiteit Eindhoven (TU/e).
 *  All Rights Reserved.
 *
 * ---------------------------------------------------------------------------
 *
 *  The contents of this file are subject to the RIACA Public License
 *  Version 1.0 (the "License"). You may not use this file except in
 *  compliance with the License. A copy of the License is available at
 *  http://www.riaca.win.tue.nl/
 *
 *  Alternatively, the contents of this file may be used under the terms
 *  of the GNU Lesser General Public license (the "LGPL license"), in which 
 *  case the provisions of the LGPL license are applicable instead of those 
 *  above. A copy of the LGPL license is available at http://www.gnu.org/
 *
 *  The Original Code is ROML -- the RIACA OpenMath Library. The Initial
 *  Developer of the Original Code is Manfred N. Riem.  Portions created
 *  by Manfred N. Riem are Copyright (c) 2001. All Rights Reserved.
 *
 *  Contributor(s):
 *
 *      Ernesto Reinaldo Barreiro, Arjeh M. Cohen, Hans Cuypers, Hans Sterk,
 *      Olga Caprotti
 *
 * ---------------------------------------------------------------------------
 */
package nl.tue.win.riaca.openmath.util;

import junit.framework.*;
import nl.tue.win.riaca.openmath.io.OMXMLReader;
import nl.tue.win.riaca.openmath.io.OMXMLWriter;
import nl.tue.win.riaca.openmath.lang.OMObject;
import org.xml.sax.InputSource;
import java.io.ByteArrayInputStream; 
import java.io.ByteArrayOutputStream;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintStream;
import java.io.StringBufferInputStream;

/**
 * A JUnit test class for the PrettyPrint class. <p>
 *
 * @author Manfred N. Riem (mriem@manorrock.org)
 * @version $Revision: 1.2 $
 */
public class PrettyPrintTest extends TestCase {
    /**
     * Constructor. <p>
     *
     * @param testName the name of the test. 
     */
    public PrettyPrintTest(String testName) {
        super(testName);
    }
    
    /**
     * Gets the suite of tests. <p>
     *
     * @return the suite.
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(PrettyPrintTest.class);
        return suite;
    }
    
    /**
     * Test of setOutputStream method, of class nl.tue.win.riaca.openmath.util.PrettyPrint.
     */
    public void testSetOutputStream() {
        PrettyPrint prettyPrint = new PrettyPrint();
        prettyPrint.setOutputStream(new ByteArrayOutputStream());
        
        assertTrue(prettyPrint.getOutputStream() != null);
    }
    
    /**
     * Test of getOutputStream method, of class nl.tue.win.riaca.openmath.util.PrettyPrint.
     */
    public void testGetOutputStream() {
        PrettyPrint prettyPrint = new PrettyPrint();
        prettyPrint.setOutputStream(new ByteArrayOutputStream());
        
        assertTrue(prettyPrint.getOutputStream() != null);
    }
    
    /**
     * Test of setInputStream method, of class nl.tue.win.riaca.openmath.util.PrettyPrint.
     */
    public void testSetInputStream() {
        PrettyPrint prettyPrint = new PrettyPrint();
        prettyPrint.setInputStream(new ByteArrayInputStream(new byte[10]));
        
        assertTrue(prettyPrint.getInputStream() != null);
    }
    
    /**
     * Test of getInputStream method, of class nl.tue.win.riaca.openmath.util.PrettyPrint.
     */
    public void testGetInputStream() {
        PrettyPrint prettyPrint = new PrettyPrint();
        prettyPrint.setInputStream(new ByteArrayInputStream(new byte[10]));
        
        assertTrue(prettyPrint.getInputStream() != null);
    }
    
    /**
     * Test of prettyPrint method, of class nl.tue.win.riaca.openmath.util.PrettyPrint.
     */
    public void testPrettyPrint() {
        try {
            PrettyPrint prettyPrint = new PrettyPrint();
            ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
        
            prettyPrint.setInputStream(new StringBufferInputStream("<OMOBJ><OMI>1</OMI></OMOBJ>"));
            prettyPrint.setOutputStream(outputStream);
            prettyPrint.prettyPrint();
        
            assertTrue(outputStream.toString().indexOf("<OMI>") != -1);
        }
        catch(Exception exception) {
            fail(exception.getMessage());
        }
    }
}
